@@ -6,7 +6,7 @@ from marshmallow_polyfield import PolyField
 from sortedcontainers import SortedDict
 
 from nitpick import fields
-from nitpick.constants import READ_THE_DOCS_URL
+from nitpick.constants import READ_THE_DOCS_URL, SETUP_CFG
 from nitpick.generic import flatten
 
 
@@ -14,13 +14,11 @@ def flatten_marshmallow_errors(errors: Dict) -> str:
     """Flatten Marshmallow errors to a string."""
     formatted = []
     for field, data in SortedDict(flatten(errors)).items():
-        if isinstance(data, list):
+        if isinstance(data, (list, tuple)):
             messages_per_field = [f"{field}: {', '.join(data)}"]
-        elif isinstance(data, dict):
-            messages_per_field = [f"{field}[{index}]: {', '.join(messages)}" for index, messages in data.items()]
         else:
-            # This should never happen; if it does, let's just convert to a string
-            messages_per_field = [str(errors)]
+            # This should not happen; if it does, let's just convert to a string
+            messages_per_field = [f"{field}: {data}"]
         formatted.append("\n".join(messages_per_field))
     return "\n".join(formatted)
 
@@ -45,8 +43,8 @@ class NitpickStylesSectionSchema(BaseNitpickSchema):
     include = PolyField(deserialization_schema_selector=fields.string_or_list_field)
 
 
-class SetupCfgSchema(BaseNitpickSchema):
-    """Validation schema for setup.cfg."""
+class IniSchema(BaseNitpickSchema):
+    """Validation schema for INI files."""
 
     error_messages = {"unknown": help_message("Unknown configuration", "nitpick_section.html#comma-separated-values")}
 
@@ -61,7 +59,7 @@ class NitpickFilesSectionSchema(BaseNitpickSchema):
     absent = fields.Dict(fields.NonEmptyString, fields.String())
     present = fields.Dict(fields.NonEmptyString, fields.String())
     # TODO: load this schema dynamically, then add this next field setup_cfg
-    setup_cfg = fields.Nested(SetupCfgSchema, data_key="setup.cfg")
+    setup_cfg = fields.Nested(IniSchema, data_key=SETUP_CFG)
 
 
 class NitpickSectionSchema(BaseNitpickSchema):
